==> vectorhub-nightly-1.0.8.2021.1.11.tar.gz: vectorhub-nightly-1.0.8.2021.1.11/vectorhub/encoders/image/tfhub/resnetv2.md <==
---
model_id: 'image/resnet-v2'
model_name: "ResNet"
vector_length: "2048 (default)"
paper: "https://arxiv.org/abs/1512.03385"
installation: "pip install vectorhub['encoders-image-tfhub']"
release_date: "2016-03-16"
category: image
---

## Description

Deeper neural networks are more difficult to train. We present a residual learning framework to ease the training of networks that are substantially deeper than those used previously. We explicitly reformulate the layers as learning residual functions with reference to the layer inputs, instead of learning unreferenced functions. We provide comprehensive empirical evidence showing that these residual networks are easier to optimize, and can gain accuracy from considerably increased depth. On the ImageNet dataset we evaluate residual nets with a depth of up to 152 layers---8x deeper than VGG nets but still having lower complexity. An ensemble of these residual nets achieves 3.57% error on the ImageNet test set. This result won the 1st place on the ILSVRC 2015 classification task. We also present analysis on CIFAR-10 with 100 and 1000 layers.

## Working in Colab

If you are using this in colab and want to save this so you don't have to reload, use: 

```
import os 
os.environ['TFHUB_CACHE_DIR'] = "drive/MyDrive/"
os.environ["TFHUB_MODEL_LOAD_FORMAT"] = "COMPRESSED"
```

## Example

```python
#pip install vectorhub['encoders-image-tfhub']
from vectorhub.encoders.image.tfhub import ResnetV22Vec
model = ResnetV22Vec()
sample = model.read('https://getvectorai.com/assets/hub-logo-with-text.png')
model.encode(sample)
```

==> vectorhub-nightly-1.2.0.2021.4.4.0.32.55.305711.tar.gz: vectorhub-nightly-1.2.0.2021.4.4.0.32.55.305711/vectorhub/encoders/image/tfhub/resnetv2.md <==
---
model_id: 'image/resnet-v2'
model_name: "ResNet"
vector_length: "2048 (default)"
paper: "https://arxiv.org/abs/1512.03385"
installation: "pip install vectorhub['encoders-image-tfhub']"
release_date: "2016-03-16"
category: image
short_description: Residual networks are 8x deeper than VGG nets but achieves lower complexity.  Then, the residual network was able to achieve 3.57% error on the ImageNet dataset.
---

## Description

Deeper neural networks are more difficult to train. We present a residual learning framework to ease the training of networks that are substantially deeper than those used previously. We explicitly reformulate the layers as learning residual functions with reference to the layer inputs, instead of learning unreferenced functions. We provide comprehensive empirical evidence showing that these residual networks are easier to optimize, and can gain accuracy from considerably increased depth. On the ImageNet dataset we evaluate residual nets with a depth of up to 152 layers---8x deeper than VGG nets but still having lower complexity. An ensemble of these residual nets achieves 3.57% error on the ImageNet test set. This result won the 1st place on the ILSVRC 2015 classification task. We also present analysis on CIFAR-10 with 100 and 1000 layers.

## Working in Colab

If you are using this in colab and want to save this so you don't have to reload, use: 

```
import os 
os.environ['TFHUB_CACHE_DIR'] = "drive/MyDrive/"
os.environ["TFHUB_MODEL_LOAD_FORMAT"] = "COMPRESSED"
```

## Example

```python
#pip install vectorhub['encoders-image-tfhub']
from vectorhub.encoders.image.tfhub import ResnetV22Vec
model = ResnetV22Vec()
sample = model.read('https://getvectorai.com/assets/hub-logo-with-text.png')
model.encode(sample)
```
